function obj = IsaacECOL(varargin)
% @IsaacECOL : constructeur
%
% (Appeler en TRY-CATCH pour sortie en erreur d'execution)
%
%	obj = IsaacECOL()
%		=> objet @IsaacECOL par dfaut indtermin
%
%  obj = IsaacECOL(name,lightsource)
%		=> objet @IsaacECOL initialis avec un espace prdfini
%
%	obj = IsaacECOL('ICC',iccfilename)
%		=> objet @IsaacECOL initialis avec un profil icc
%
%	obj = IsaacECOL(filename)
%		=> objet @IsaacECOL lu dans un fichier
%
%	- name			: nom de l'espace colorimtrique
%	- lightsource	: nom de l'illuminant ou '?' si indtermin
%	- iccfilename	: nom court du fichier profil icc dans le rpertoire Profils d'Isaac
%	- filename		: nom du fichier dans rpertoire courant ou nom complet				
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

% 	name			: nom de l'espace colorimtrique
%						- 'SRGB' : standard computer monitor RGB (IEC 61966-2-1)
%						- 'XYZ'	: 1931 CIE XYZ tristimulus (2 observer)
%						- 'XYL'	: 1931 CIE xyY chromaticity (2 observer)
%						- 'LAB'	: 1976 CIE L*a*b*
%						- 'LCH'	: CIE L*a*b* en coordonnes polaires
%						- 'UVL'	: 1960 CIE uvL
%						- 'UpVpL': 1960 CIE u'v'L
%						- 'HSV'	: HSV hue-saturation-value
%						- 'YIQ'	: NTSC tlvision
%						- 'YCbCr': YCbCr vido numrique
%						- 'ICC'	: si profil ICC correspondant
%
%  dimension	: dimension de l'espace colorimtrique ou 0 si indtermine
%						- 3 pour les images couleur classiques
%
%	bitclass		: classe(s) de bits autorise(s)
%						- matrice(1,1  4) de 8/16/32/64
%
% 	lightsource	: nom de l'illuminant ou '?' si indtermin
%						- 'D50', 'D55', 'D65'(= lumire du jour), 'D75', 'A', 'C', 'E',
%						- 'ICC' si profil ICC correspondant
%
% 	whitepoint	: point blanc de rfrence ou [] si indtermin
%						- [x,y,z] coordonnes XYZ telles que y = 1 (cf fonction matlab)			
%
% 	gamma			: valeur de correction gamma ou 1 par dfaut
%
%	iccprofile	: profil ICC ou [] si name ~= 'ICC'
%	iccfilename	: nom court du fichier profil ou '' si name ~= 'ICC'
%
%	version		: version de l'objet 

%---------------------------------------------------------------------------------------------------

objversion = 1;

%---------------------------------------------------------------------------------------------------

                                                                                         %[tomodify]
% conversion LCH (double) supprime car rsultats plan H entre 50 et 500 (bug Matlab 2007a ?)

global ISAACCONST

switch nargin
	case 0
		% Objet par dfaut indtermin
		obj.name = '';
		obj.dimension = 0;
		obj.bitclass = [];
		obj.lightsource = '?';
		obj.whitepoint = [];
		obj.gamma = 1;
		obj.iccprofile = [];
		obj.iccfilename = '';
		obj.version = objversion;
		obj = class(orderfields(obj),'IsaacECOL'); % orderfields car class est sensible  l'ordre
	case 2
		% Objet initialis
		if strcmp(char(varargin{1}),'ICC')
			obj.name = 'ICC';
			obj.iccfilename = varargin{2};
			try	
				obj.iccprofile = iccread(fullfile(ISAACCONST.ProfilsDir,obj.iccfilename));
				if ~isicc(obj.iccprofile)
					error('pour provoquer le catch')
				end
			catch
				error(['fichier profil ICC ',obj.iccfilename,' invalide'])
			end
			obj.lightsource = 'ICC';
			try
				obj.whitepoint = obj.iccprofile.MediaWhitePoint;
			catch
				obj.whitepoint = whitepoint('icc');
			end
			obj.dimension = 0;			% valeur attribue par dfaut
			obj.bitclass = [8,16,64];	% valeur attribue par dfaut
			obj.gamma = 1;					% valeur attribue par dfaut
		else
			obj.name = char(varargin{1});
			[obj.bitclass,obj.dimension] = IsaacColorType(obj.name);
			if isempty(obj.bitclass)
				error('espace colorimtrique inconnu ou non gr')
			end
			obj.lightsource = char(varargin{2});
			obj.whitepoint = IsaacWhitePoint(obj.lightsource);
			if (obj.whitepoint == 0)
				error('illuminant inconnu ou non gr')
			end
			obj.gamma = 1;					% valeur attribue par dfaut
			obj.iccprofile = [];
			obj.iccfilename = '';
		end	
		obj.version = objversion;
		obj = class(orderfields(obj),'IsaacECOL'); % orderfields car class est sensible  l'ordre	
	case 1
		% Lecture dans un fichier
		try
			warning off
			var = load('-mat',varargin{1},'ECOL'); % variable ECOL dans le fichier
			warning on
			obj = var.ECOL;
			if ~isa(obj,'IsaacECOL')
				% erreur affiche par loadobj
				error('pour provoquer le catch')
			end
		catch
			error('fichier invalide')
		end
	otherwise
		error('nombre d''arguments incorrect')
end
