function [h,c] = IsaacHistN(varargin)
% Histogramme multidimensionnel compact pour matrices de donnes  P>=1 composantes relles
% 	- sans valeurs nulles.
% 	- tri par algorithme de quicksort lexicographique sur les P dimensions.
% 	- born ventuellement sur chacune des P dimensions.
%
% Usage [h,c]=IsaacHistN(d,limits) ou [h,c]=IsaacHistN(d) 
%
% 	d		: matrice MxN (P=1) ou tableau MxNxP (P>1) des donnes.
% 	limits	: matrice 2xP (P>=1) des min (ligne1) et max (ligne2) des valeurs  prendre en compte. 
% 	h		: matrice LxP (P>=1) de l'histogramme compact  L P-uplets tris.
% 	c		: matrice Lx1 des effectifs pour chaque P-uplet de h.
%
% 	d,limits,h,c de type double
%	
% Si les valeurs de limits ne peuvent tres satisfaites, h et c retourns sont vides.	
%
% D'aprs la thse de Alain Clment (Universit d'Angers - juillet 2002)
%
% Algorithm for OpenIsaac
% version 1
%  2002-2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

if ismac  
	if verLessThan('matlab', '9.3') 
      % MATLAB 2017a et antrieur
      [h,c] = histn_mac2010b(varargin{:});
   else
      % MATLAB 2017b (9.3) et postrieur
      [h,c] = histn_mac2017b(varargin{:});
	end   
elseif ispc
	if verLessThan('matlab', '9.3') 
      % MATLAB 2017a et antrieur
      [h,c] = histn_win2013b(varargin{:});
   else
      % MATLAB 2017b (9.3) et postrieur
      [h,c] = histn_win2017b(varargin{:});
	end   
else
    error('mexfile inexistant')     
end
end
