function obj = IsaacIMG_fillmask(obj,obj2,mask)
% @IsaacIMG : remplit obj avec avec obj2 selon mask
%           ROI et espace colorimtrique inchangs
%
%    - obj2 : objet @IsaacIMG
%    - mask : masque binaire
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

global ISAACPREF

if verLessThan('matlab', '7.11') 
	% code pour MATLAB 2010a et antrieur
	test_mat = (ndims(mask) == 2);                                                               %#ok
else
	% code pour MATLAB 2010b (7.11) et postrieur  
	test_mat = ismatrix(mask);
end

if ~isa(obj2,'IsaacIMG') || ~isa(mask,'logical') || ~test_mat
	error('argument incorrect')                                                                 
end
% requantification ventuelle
if (obj2.nbb ~= obj.nbb)
	img = IsaacIMG_im2nbb(obj2,obj.nbb);
	if (obj.nbb == 1)
		IsaacMessageWarning(['image ',obj2.imgname,' convertie en logical'])
	else
		IsaacMessageWarning(['image ',obj2.imgname,' convertie en ',num2str(obj.nbb),' bits'])
	end	
else
	img = obj2.img;
end
% redimensionnement ventuel
if ((obj2.dimx ~= obj.dimx) || (obj2.dimy ~= obj.dimy))
	img2 = imresize(img,[obj.dimy,obj.dimx],'nearest');
	IsaacMessageWarning(['image ',obj2.imgname,' redimensionne'])	
else
	img2 = img;
end
clear img
if (size(mask,1) ~= obj.dimy) || (size(mask,2) ~= obj.dimx)
	mask2 = imresize(mask,[obj.dimy,obj.dimx],'nearest');
	IsaacMessageWarning('masque redimensionn')	
else
	mask2 = mask;
end
clear mask
dimz = obj.dimz;
if (obj2.dimz > obj.dimz)
	IsaacMessageWarning(['plans surnumraires de ',obj2.imgname,' ignors'])
elseif (obj2.dimz < obj.dimz)
	dimz = obj2.dimz;
	IsaacMessageWarning(['plans surnumraires de ',obj.imgname,' ignors'])
end
% remplissage du masque
for k = 1:dimz
	p1 = obj.img(:,:,k);
	p2 = img2(:,:,k);
	p1(mask2) = p2(mask2);
	obj.img(:,:,k) = p1;
end
if (obj.dimz == 1)
	obj.min = double(min(min(obj.img)));
	obj.max = double(max(max(obj.img)));
else
	obj.min = reshape(double(min(min(obj.img))),1,obj.dimz); % (matrice 1xdimz)
	obj.max = reshape(double(max(max(obj.img))),1,obj.dimz); % (matrice 1xdimz)
end
if ~ISAACPREF.OptimiseImgMem
	% recalcul masque de roi valeurs
	obj.roivalmask = IsaacROI_valmask(obj.roi,obj.img);
end