function obj = IsaacIMG_mat2img(obj,mat,varargin)
% @IsaacIMG : remplace la matrice image de obj 
%
%	obj = IsaacIMG_mat2img(obj,mat) 
%		=> conversion si ncessaire de mat pour conservation du nbbits de obj
%
%	obj = IsaacIMG_mat2img(obj,mat,'ChangeBits') 
%		=> nbbits de obj forc dans le type Matlab de mat
%		   (logical/uint8/uint16/single/double -> 1/8/16/32/64)
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

global ISAACPREF

olddimx = obj.dimx;
olddimy = obj.dimy;
olddimz = obj.dimz;
oldnbb = obj.nbb;
oldbitclass = obj.bitclass;
switch nargin
case 2
	obj = IsaacObjIMGInit(obj,mat);
	clear mat
	if (obj.nbb ~= oldnbb)
		% rtablissement du nb de bits
		if ~IsaacBitCheck(obj.img,oldnbb)
			obj.img = IsaacIMG_im2nbb(obj,oldnbb);
			if (obj.dimz == 1)
				obj.min = double(min(min(obj.img)));
				obj.max = double(max(max(obj.img)));
			else
				obj.min = reshape(double(min(min(obj.img))),1,obj.dimz); % (matrice 1xdimz)
				obj.max = reshape(double(max(max(obj.img))),1,obj.dimz); % (matrice 1xdimz)
			end
		end	
		obj.nbb = oldnbb;
		obj.bitclass = oldbitclass;
		obj.valmax = IsaacValMax(obj.nbb);
	end	
case 3	
	if strcmp(varargin{1},'ChangeBits')
		obj = IsaacObjIMGInit(obj,mat);
		clear mat
	else
		error('argument incorrect')
	end
otherwise
	error('nombre d''arguments incorrect')
end
ChangeXY = (olddimx ~= obj.dimx) || (olddimy ~= obj.dimy);
ChangeZ = (olddimz ~= obj.dimz);
ChangeB = (oldnbb ~= obj.nbb);
if (ChangeXY || ChangeZ || ChangeB)
	if obj.isroi
		IsaacMessageWarning('rgion d''intrt ajuste  l''image')
	end
	if ChangeXY
		% Ajustement de roi spatiale
		obj.roi = IsaacROI_adjust(obj.roi,'RoiSpa',obj.dimx,obj.dimy);
		if ~ISAACPREF.OptimiseImgMem
			% recalcul masque de roi spatiale
			obj.roispamask = IsaacROI_spamask(obj.roi);
		end
	end
	if (ChangeZ || ChangeB)
		% Ajustement de roi valeurs
		obj.roi = IsaacROI_adjust(obj.roi,'RoiVal',obj.dimz,obj.nbb);
		if (obj.iscolorspace && ~IsaacECOL_check(obj.colorspace,obj.dimz,obj.bitclass))
			IsaacMessageWarning('espace colorimtrique incompatible supprim')
			% Effacement espace colorimtrique
			obj.colorspace = IsaacECOL(); % espace indtermin par dfaut
			obj.iscolorspace = false;
		end	
	end
end
if ~ISAACPREF.OptimiseImgMem
	% recalcul masque de roi valeurs
	obj.roivalmask = IsaacROI_valmask(obj.roi,obj.img);
end
