function [ok,obj] = IsaacIMG_saveas(obj,filename)
% @IsaacIMG : criture d'un objet @IsaacIMG dans un fichier avec maj du nom de l'image
%
% (Appeler en TRY-CATCH pour sortie en erreur d'execution)
%
%	- filename	: nom du fichier dans rpertoire courant ou nom complet
%	- ok        : true si sauvegarde  l'identique (sans conversion), false sinon
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

global ISAACCONST

[~,newname,ext] = fileparts(filename);
switch(ext)
	case ISAACCONST.ExtImg
		IMG = obj;
		IMG.imgname = newname;
		IMG.converted = false;
		save(filename,'IMG','-mat') % variable IMG dans le fichier
		ok = true;
	case '.bmp'
		ok = true;
		if (((obj.dimz == 3) && (obj.bitclass == 1)) || ((obj.dimz ~=1) && (obj.dimz ~=3)))
			error('sauvegarde images multicomposantes impossible en BMP')
			ok = false;
			return
		end
		if obj.isroi
			IsaacMessageWarning('rgion d''intrt non sauvegarde en BMP')
			ok = false;
		end
		if obj.iscolorspace
			IsaacMessageWarning('espace colorimtrique non sauvegard en BMP')
			ok = false;
		end	
		if (obj.bitclass > 8)
			IsaacMessageWarning(['image ',filename],'convertie en 8 bits pour format BMP')
			img = IsaacIMG_im2nbb(obj,8);
			ok = false;
		else	
			img = obj.img;
		end
		imwrite(img,filename,'bmp')
	case '.tif'
		ok = true;
		if ((obj.dimz == 3) && (obj.bitclass == 1))
			error('sauvegarde images multicomposantes 1 bit impossible en TIF')
			ok = false;
			return
		end
		if obj.isroi
			IsaacMessageWarning('rgion d''intrt non sauvegarde en TIF')
			ok = false;
		end
		if obj.iscolorspace
			IsaacMessageWarning('espace colorimtrique non sauvegard en TIF')
			ok = false;
		end	
		if (obj.bitclass > 16)
			IsaacMessageWarning(['image ',filename],'convertie en 16 bits pour format TIF')
			img = IsaacIMG_im2nbb(obj,16);
			ok = false;
		else	
			img = obj.img;
		end
		if (obj.dimz ~=1) && (obj.dimz ~=3)
			imwrite(img(:,:,1),filename,'tif','Compression','none')
			for i = 2:obj.dimz
				imwrite(img(:,:,i),filename,'tif','Compression','none','WriteMode','append')
			end
		else
			imwrite(img,filename,'tif','Compression','none')
		end
	otherwise
		error('format d''image incorrect')
end
obj.converted = false; % maj aprs criture fichier si ancienne version convertie
if ~strcmp(newname,obj.imgname)
	% mise  jour du nom de l'image avec le nom du fichier
	obj.imgname = newname;
end
		