function obj = IsaacIMG_set(obj,varargin)
% @IsaacIMG : criture d'une ou plusieurs proprits
%     Avertissement au cas o ROI ajuste ou espace colorimtrique supprim
%
% (Appeler en TRY-CATCH pour sortie en erreur d'execution)
%
%	obj = IsaacIMG_set(obj,propname1,val1,...,propnameN,valN)
%
% propname		val
% --------		---
% 'ColorSpace'	obj.colorspace ou []
% 'Img'			obj.img
% 'ImgName'		obj.imgname (si '' alors obj.imgname = 'SansNom')
% 'NbBitsUsed'	obj.nbb (dans les limites de bitclass si cela est possible)
% 'Roi'			obj.roi (optimis) ou []				
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

global ISAACPREF

if (nargin < 3)
	error('nombre d''arguments incorrect')
end
propargin = varargin;
while (length(propargin) >= 2)
	propname = propargin{1};
	val = propargin{2};
	propargin = propargin(3:end);
	switch propname
		case 'ColorSpace'
			if isempty(val)
				obj.colorspace = IsaacECOL(); % espace indtermin par dfaut
				obj.iscolorspace = false;
			elseif isa(val,'IsaacECOL')
				if ~IsaacECOL_check(val,obj.dimz,obj.bitclass)
					error('espace colorimtrique incompatible avec l''image')
				end	
				obj.colorspace = val;
				obj.iscolorspace = true;
			else
				error('argument incorrect')
			end
		case 'Img'
			olddimx = obj.dimx;
			olddimy = obj.dimy;
			olddimz = obj.dimz;
			oldnbb = obj.nbb;
			obj = IsaacObjIMGInit(obj,val);
			clear val
			% conservation du nb de bits si compatible avec les valeurs de img
			if IsaacBitCheck(obj.img,oldnbb)
				obj.nbb = oldnbb;
				obj.valmax = IsaacValMax(obj.nbb);
			end
			ChangeXY = (olddimx ~= obj.dimx) || (olddimy ~= obj.dimy);
			ChangeZ = (olddimz ~= obj.dimz);
			ChangeB = (oldnbb ~= obj.nbb);
			if (ChangeXY || ChangeZ || ChangeB)
				if obj.isroi
					IsaacMessageWarning('rgion d''intrt ajuste  l''image')
				end
				if ChangeXY
					% Ajustement de roi spatiale
					obj.roi = IsaacROI_adjust(obj.roi,'RoiSpa',obj.dimx,obj.dimy);
					if ~ISAACPREF.OptimiseImgMem
						% recalcul masque de roi spatiale
						obj.roispamask = IsaacROI_spamask(obj.roi);
					end
				end
				if (ChangeZ || ChangeB) 
					% Ajustement de roi valeurs
					obj.roi = IsaacROI_adjust(obj.roi,'RoiVal',obj.dimz,obj.nbb);
					if (obj.iscolorspace && ~IsaacECOL_check(obj.colorspace,obj.dimz,obj.bitclass))
						IsaacMessageWarning('espace colorimtrique incompatible supprim')
						% Effacement espace colorimtrique
						obj.colorspace = IsaacECOL(); % espace indtermin par dfaut
						obj.iscolorspace = false;
					end	
				end
			end
			if ~ISAACPREF.OptimiseImgMem
				% recalcul masque de roi valeurs
				obj.roivalmask = IsaacROI_valmask(obj.roi,obj.img);
			end
		case 'ImgName'
			if isempty(val)
				obj.imgname = 'SansNom';
			else	
				obj.imgname = val;
			end	
		case 'NbBitsUsed'
			if IsaacBitCheck(obj.img,val)
				obj.nbb = val;
				obj.valmax = IsaacValMax(obj.nbb);
			else	
				error('nombre de bits incompatible avec l''image')
			end	
			% Ajustement de roi
			obj.roi = IsaacROI_adjust(obj.roi,'NBBits',obj.nbb);
			if obj.isroi 
				if ~ISAACPREF.OptimiseImgMem
					% si ~obj.isroi le masque valeur reste  false de dimension inchange
					% recalcul masque de roi valeurs
					obj.roivalmask = IsaacROI_valmask(obj.roi,obj.img);
				end
			end
			% Espace colorimtrique inchang car la classe de bits n'a pas chang
		case 'Roi'
			if isempty(val)
				obj.roi = IsaacROI(obj.dimx,obj.dimy,obj.dimz,obj.nbb); % roi inactive par dfaut
				obj.isroi = false;
			elseif isa(val,'IsaacROI')
				obj.roi = IsaacROI_optimise(val);
				if ~IsaacROI_check(obj.roi,obj.dimx,obj.dimy,obj.dimz,obj.nbb)
					IsaacMessageWarning('rgion d''intrt ajuste  l''image')
					obj.roi = IsaacROI_adjust(obj.roi,'RoiSpaVal',obj.dimx,obj.dimy,obj.dimz,obj.nbb);
				end
				obj.isroi = true;
			else
				error('argument incorrect')
			end
			if ~ISAACPREF.OptimiseImgMem
				if obj.isroi
					obj.roispamask	= IsaacROI_spamask(obj.roi);
					obj.roivalmask	= IsaacROI_valmask(obj.roi,obj.img);
				else
					obj.roispamask	= false(obj.dimy,obj.dimx);
					obj.roivalmask	= false(obj.dimy,obj.dimx);
				end
			end	
		otherwise
			error('argument incorrect')
	end
end
if ~isempty(propargin)
	error('nombre d''arguments incorrect')
end
