function IsaacImage_set(obj,auteur,varargin)
% @IsaacImage : criture d'une ou plusieurs proprits
%
% (Appeler en TRY-CATCH pour sortie en erreur d'execution)
%
%	IsaacImage_set(obj,auteur,propname1,val1,...,propnameN,valN)
%
%	- auteur	: handle figure outil appelante
%
% propname		val
% --------		---
% 'Echelle'		obj.echelle ATTENTION : l'chelle effective pourra tre diffrente
% 'ECOL'		objet @IsaacECOL ou []
% 'IMG'			objet @IsaacIMG
% 'ImgR'		contenu rel de l'image obj.img
% 'NbBitsUsed'	nombre de bits utiliss (dans les limites de la classe si c'est possible)
% 'ParamA'		structure = paramtres d'affichage
% 'ParamARoi'	structure = paramtres d'affichage de ROI
% 'ROI'			objet @IsaacROI ou []
% 'Zoom'		zoom 'on', 'off' ou 'reset'
%
% @-> EVENEMENTS 31/32/41/42/51/52/61/62/71/72/81/82/91/92/101/102/111/112
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------
% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

global ISAACPRIV
global ISAACPREF
global ISAACCONST

if (nargin < 4)
	error('nombre d''arguments incorrect')
end
propargin = varargin;
while (length(propargin) >= 2)
	propname = propargin{1};
	val = propargin{2};
	propargin = propargin(3:end);
	switch propname
		case 'Echelle'
			if (val <= 0)
				error('valeur chelle incorrecte')
			end	
			DimX = IsaacIMG_get(obj.img,'DimX');
			DimY = IsaacIMG_get(obj.img,'DimY');
			obj.echelle = IsaacImgScale(val,DimX,DimY); % val = chelle souhaite
			% Modif proprit position fentre, bouton select et axes
			RescaleImg
			% EVENEMENT
			if (obj == ISAACPRIV.Cible)
				IsaacImage_event(obj,auteur,101)
			else
				IsaacImage_event(obj,auteur,102)
			end
		case 'ECOL'
			obj.img = IsaacIMG_set(obj.img,'ColorSpace',val);
			% Modif titre image
			set(obj.fighnd,'Name',IsaacImage_title(obj))
			% Maj status
			if (obj.status ~= -1)
				obj.status = 0;
			end
			% EVENEMENT
			if (obj == ISAACPRIV.Cible)
				% maj marque image
				set(findobj(obj.fighnd,'Tag','ButSelect'),'BackgroundColor',ISAACPREF.CibleColor2)
				IsaacImage_event(obj,auteur,81)
			else
				IsaacImage_event(obj,auteur,82)
			end
		case {'IMG','ImgR'}
			if strcmp(propname,'IMG')
 				if (obj.status ~= -1)
					[~,name] = fileparts(obj.filename);
					if ~strcmp(name,IsaacIMG_get(val,'ImgName'))
						obj.status = -1;
						obj.filename = '';
					end
				end
				ChangeROI	= ~IsaacIMG_compare(obj.img,val,'Roi');
				ChangeECOL	= ~IsaacIMG_compare(obj.img,val,'ColorSpace');
				ChangeImg	= ~IsaacIMG_compare(obj.img,val,'Img');
				ChangeName	= ~IsaacIMG_compare(obj.img,val,'ImgName');
				ChangeZ		= ~IsaacIMG_compare(obj.img,val,'DimZ');
				ChangeB		= ~IsaacIMG_compare(obj.img,val,'Bits');
				ChangeXY	= ~IsaacIMG_compare(obj.img,val,'DimXY');
				% remplacement de obj.img par val
				obj.img = val;
			else
				% modification contenu rel de obj.img
				img = IsaacIMG_set(obj.img,'Img',val);
				ChangeROI	= ~IsaacIMG_compare(obj.img,img,'Roi');
				ChangeECOL	= ~IsaacIMG_compare(obj.img,img,'ColorSpace');
				ChangeImg	= true;
				ChangeName	= false;
				ChangeZ		= ~IsaacIMG_compare(obj.img,img,'DimZ');
				ChangeB		= ~IsaacIMG_compare(obj.img,img,'Bits');
				ChangeXY	= ~IsaacIMG_compare(obj.img,img,'DimXY');
				obj.img = img;
				clear img
			end	
			clear val
			if ChangeROI
				% Modif. params affichage ROI
				if ~IsaacIMG_get(obj.img,'IsRoi')
					obj.showRoiSpa = 0;
					obj.showRoiVal = 0;
					obj.showRoiComp = false;
				else	
					if ~IsaacIMG_get(obj.img,'IsRoiSpa')
						obj.showRoiSpa = 0;
					end
					if ~IsaacIMG_get(obj.img,'IsRoiVal')
						obj.showRoiVal = 0;
					end
				end
			end
			if ChangeZ
				% Modif. params affichage
				DimZ = IsaacIMG_get(obj.img,'DimZ');
				for i = 1:3
					if obj.plan(i) > DimZ
						obj.plan(i) = DimZ;
					end
				end
				if (DimZ < 3)
					obj.plan = [obj.plan(1),obj.plan(1),obj.plan(1)];
					obj.marginal = true;
				else
					obj.marginal = all(obj.plan == obj.plan(1));
				end
			end
			if ChangeB
				% Modif. params affichage
				if (IsaacIMG_get(obj.img,'NbBits') == 1)
					obj.ED = false;
					obj.gammaA = 1;
					obj.pal = 1;
				end 
			end	
			if ChangeXY
				DimX = IsaacIMG_get(obj.img,'DimX');
				DimY = IsaacIMG_get(obj.img,'DimY');
				obj.echelle = IsaacImgScale(obj.echelle,DimX,DimY); % mme chelle souhaite
				% Modif proprit position fentre, bouton select et axes
				RescaleImg
				% Modif. axes et reset du zoom (=> reset et pas dsactivation)
				set(obj.axImg,'XLim',[1 DimX],'YLim',[1 DimY])
				set(get(obj.axImg,'Children'),'XData',[1 DimX],'YData',[1 DimY]) % image
			end
			if ChangeName || ChangeB || ChangeZ || ChangeECOL
				% Modif titre image
				set(obj.fighnd,'Name',IsaacImage_title(obj))
			end
			% Maj status
			if (obj.status ~= -1)
				obj.status = 0;
			end
			if (obj == ISAACPRIV.Cible)
				% maj marque image cible
				set(findobj(obj.fighnd,'Tag','ButSelect'),'BackgroundColor',ISAACPREF.CibleColor2)
			end
			% Affichage
			IsaacImage_draw(obj)
			% EVENEMENT
			if (ChangeXY || ChangeZ || ChangeB || (ChangeROI && ChangeECOL))
				if (obj == ISAACPRIV.Cible)
					IsaacImage_event(obj,auteur,31)
				else
					IsaacImage_event(obj,auteur,32)
				end
			elseif (ChangeImg && ChangeROI)
				if (obj == ISAACPRIV.Cible)
					IsaacImage_event(obj,auteur,41)
				else
					IsaacImage_event(obj,auteur,42)
				end
			elseif (ChangeImg && ChangeECOL)
				if (obj == ISAACPRIV.Cible)
					IsaacImage_event(obj,auteur,51)
				else
					IsaacImage_event(obj,auteur,52)
				end
			elseif ChangeImg
				if (obj == ISAACPRIV.Cible)
					IsaacImage_event(obj,auteur,61)
				else
					IsaacImage_event(obj,auteur,62)
				end
			elseif ChangeROI
				if (obj == ISAACPRIV.Cible)
					IsaacImage_event(obj,auteur,71)
				else
					IsaacImage_event(obj,auteur,72)
				end
			elseif ChangeECOL
				if (obj == ISAACPRIV.Cible)
					IsaacImage_event(obj,auteur,81)
				else
					IsaacImage_event(obj,auteur,82)
				end
			end	
			if ChangeName
				if (obj == ISAACPRIV.Cible)
					IsaacImage_event(obj,auteur,111)
				else
					IsaacImage_event(obj,auteur,112)
				end
			end
		case 'NbBitsUsed'
			if (val == IsaacIMG_get(obj.img,'NbBits'))
				return
			end	
			obj.img = IsaacIMG_set(obj.img,'NbBitsUsed',val);
			% Modif titre image
			set(obj.fighnd,'Name',IsaacImage_title(obj))
			% Maj status
			if (obj.status ~= -1)
				obj.status = 0;
			end
			% Maj paramtres d'affichage
			if (val == 1)
				obj.ED = false;
				obj.gammaA = 1;
				obj.pal = 1;
			end
			% Affichage
			IsaacImage_draw(obj)
			% EVENEMENT
			if (obj == ISAACPRIV.Cible)
				% maj marque image
				set(findobj(obj.fighnd,'Tag','ButSelect'),'BackgroundColor',ISAACPREF.CibleColor2)
				IsaacImage_event(obj,auteur,31)
			else
				IsaacImage_event(obj,auteur,32)
			end
		case 'ParamA'
			DimZ = IsaacIMG_get(obj.img,'DimZ');
			if ((length(val.plan) ~= 3) || any(val.plan < 1) || any(val.plan > DimZ) || ...
					(~val.marginal && (DimZ < 3)))
				error('plans affichs incompatibles')
			end	
			obj.plan = val.plan;
			if ~islogical(val.marginal)
				error('valeur marginal incorrecte')
			end	
			obj.marginal = val.marginal;
			if ~islogical(val.ED)
				error('valeur ED incorrecte')
			end
			obj.ED = val.ED;
			if (val.gamma < 0)
				error('valeur gamma incorrecte')
			end	
			obj.gammaA = val.gamma;
			if ((val.pal < 1) || (val.pal > length(ISAACCONST.PalStr)))
				error('indice palette incorrect')
			end
			obj.pal = val.pal;
			% Affichage
			IsaacImage_draw(obj)
			% EVENEMENT
			if (obj == ISAACPRIV.Cible)
				IsaacImage_event(obj,auteur,91)
			else
				IsaacImage_event(obj,auteur,92)
			end	
		case 'ParamARoi'
			if (~ismember(val.showRoiSpa,[0,1,2]) || ...
				(~IsaacIMG_get(obj.img,'IsRoiSpa') && (val.showRoiSpa ~= 0)))
				error('valeur showRoiSpa incompatible')
			end
			obj.showRoiSpa = val.showRoiSpa;
			if (~ismember(val.showRoiVal,[0,1,2]) || ...
				(~IsaacIMG_get(obj.img,'IsRoiVal') && (val.showRoiVal ~= 0)))
				error('valeur showRoiVal incompatible')
			end	
			obj.showRoiVal = val.showRoiVal;
			if (~islogical(val.showRoiComp) || ...
				(~IsaacIMG_get(obj.img,'IsRoi') && val.showRoiComp))
				error('valeur showRoiComp incompatible')
			end	
			obj.showRoiComp = val.showRoiComp;
			% Affichage
			IsaacImage_draw(obj)
			% EVENEMENT
			if (obj == ISAACPRIV.Cible)
				IsaacImage_event(obj,auteur,91)
			else
				IsaacImage_event(obj,auteur,92)
			end	
		case 'ROI'
			obj.img = IsaacIMG_set(obj.img,'Roi',val);
			% Maj status
			if (obj.status ~= -1)
				obj.status = 0;
			end
			actualshowroi = (obj.showRoiSpa~=0) || (obj.showRoiVal~=0) || obj.showRoiComp;
			% Modif. params affichage ROI
			if isempty(val)
				obj.showRoiSpa = 0;
				obj.showRoiVal = 0;
				obj.showRoiComp = false;
			else	
				% Modif. params affichage
				if ~IsaacIMG_get(obj.img,'IsRoiSpa')
					obj.showRoiSpa = 0;
				end
				if ~IsaacIMG_get(obj.img,'IsRoiVal')
					obj.showRoiVal = 0;
				end
			end	
			if actualshowroi
				% Affichage
				IsaacImage_draw(obj)
			end	
			% EVENEMENT
			if (obj == ISAACPRIV.Cible)
				% maj marque image
				set(findobj(obj.fighnd,'Tag','ButSelect'),'BackgroundColor',ISAACPREF.CibleColor2)
				IsaacImage_event(obj,auteur,71)
			else
				IsaacImage_event(obj,auteur,72)
			end	
		case 'Zoom'
			switch val
				case {'on','off'}
					obj.zoom = strcmp(val,'on');
					zoom(obj.fighnd,val)
					% EVENEMENT
					if (obj == ISAACPRIV.Cible)
						IsaacImage_event(obj,auteur,101)
					else
						IsaacImage_event(obj,auteur,102)
					end
				case 'out'
					zoom(obj.fighnd,'out')
				otherwise	
					error('valeur zoom incorrecte')	
			end
		otherwise
			error('argument incorrect')
	end
end		
if ~isempty(propargin)
	error('nombre d''arguments incorrect')
end

% --- Nested fonction ------------------------------------------------------------------------------

function RescaleImg
% Modif proprit position fentre, bouton select et axes

% intrieur fentre en coord. Matlab
oldpos = get(obj.fighnd,'Position');
% coin extrieur en haut  gauche de la fentre en coord. Matlab
oldlefttop = [oldpos(1) - ISAACCONST.EpFen(3), ...
	oldpos(2) + ISAACCONST.EpFen(2) + oldpos(4) + ISAACCONST.EpFen(1)];
% coin extrieur en haut  gauche de la fentre en coord. Isaac
oldlefttop2 = [oldlefttop(1) - ISAACCONST.Screen.refpos(1), ...
	ISAACCONST.Screen.refpos(2) - oldlefttop(2)];
% ajustement position fentre en coord. Matlab (+ ISAACCONST.EpButCible pour place bouton select)
pos = IsaacFenPos(oldlefttop2(1),oldlefttop2(2), ...
	round(DimX * obj.echelle),round(DimY * obj.echelle) + ISAACCONST.EpButCible,0);
set(obj.fighnd,'Position',pos)
HauteurImage = pos(4)-ISAACCONST.EpButCible;
LargeurImage = pos(3);
% ajustement position bouton select
set(findobj(obj.fighnd,'Tag','ButSelect'), ...
	'Position',[0 HauteurImage LargeurImage ISAACCONST.EpButCible])
% ajustement position axes
set(obj.axImg,'Position', [0  0 LargeurImage HauteurImage])
end % fin nested fonction

%---------------------------------------------------------------------------------------------------

end % fin IsaacImage_set en raison des nested fonctions
