function obj = IsaacROI_adjust(obj,propname,varargin)
% @IsaacROI : ajuste les intervalles spatiaux et valeurs  une nouvelle image de rfrence
%				  avec suppression des doublons
%
% propname		varargin
% --------		--------
% 'NBBits'		nbb
% 'NbPlans'		dimz
% 'RoiSpa'		dimx,dimy
% 'RoiVal'		dimz,nbb
% 'RoiSpaVal'	dimx,dimy,dimz,nbb
%
%	- dimx,dimy,dimz,nbb : dimensions et nbbits nouvelle image de rfrence
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

global ISAACCONST

switch propname
	case 'NBBits'
		if (nargin == 3)
			nbb = varargin{1};
			AdjustBits
		else
			error('nombre d''arguments incorrect')
		end	
	case 'NbPlans'
		if (nargin == 3)
			dimz = varargin{1};
			AdjustPlans
		else
			error('nombre d''arguments incorrect')
		end	
	case 'RoiSpa'
		if (nargin == 4)
			dimx = varargin{1};
			dimy = varargin{2};
			AdjustSpa
		else
			error('nombre d''arguments incorrect')
		end	
	case 'RoiVal'
		if (nargin == 4)
			dimz = varargin{1};
			nbb = varargin{2};
			AdjustPlans
			AdjustBits
		else
			error('nombre d''arguments incorrect')
		end	
	case 'RoiSpaVal'
		if (nargin == 6)
			dimx = varargin{1};
			dimy = varargin{2};
			dimz = varargin{3};
			nbb = varargin{4};
			AdjustSpa
			AdjustPlans
			AdjustBits
		else
			error('nombre d''arguments incorrect')
		end	
	otherwise
		error('argument incorrect')
end
% Suppression des doublons ventuels
obj = IsaacROI_optimise(obj);

% --- Nested fonction ------------------------------------------------------------------------------

function AdjustSpa

if ((dimx < 2) || (dimy < 2))
	error('argument incorrect')
end	
% Ajustement spatial
if obj.spa_nb
	obj.spa_mat(obj.spa_mat(:,1) > dimx,1) = dimx; % xmin
	obj.spa_mat(obj.spa_mat(:,2) > dimx,2) = dimx; % xmax
	obj.spa_mat(obj.spa_mat(:,3) > dimy,3) = dimy; % ymin
	obj.spa_mat(obj.spa_mat(:,4) > dimy,4) = dimy; % ymax
end
obj.ima_dimx = dimx;
obj.ima_dimy = dimy;

end % fin nested fonction

% --- Nested fonction ------------------------------------------------------------------------------

function AdjustPlans

if ((dimz < 1) || (dimz > ISAACCONST.ImMaxZ))
	error('argument incorrect')
end	
% Ajustement nb de plans
if obj.ima_dimz > dimz
	obj.isval(dimz+1:end) = [];
	if obj.val_nb
		obj.val_mat(:,2*dimz+1:end) = [];
	end	
elseif obj.ima_dimz < dimz
	obj.isval(end+1:dimz) = false;
	if obj.val_nb
		for i = obj.ima_dimz+1:dimz
			obj.val_mat(:,2*i-1) = 0;
			obj.val_mat(:,2*i) = obj.valmax;
		end
	end	
end
obj.ima_dimz = dimz;

end % fin nested fonction

% --- Nested fonction ------------------------------------------------------------------------------

function AdjustBits

if ~ismember(nbb,[1:16,32,64])
	error('argument incorrect')
end	
% Ajustement nb de bits	
if (nbb ~= obj.ima_nbb)
	if (nbb == 1)
      if obj.val_nb
         if verLessThan('matlab', '9.0') 
            % code pour MATLAB 2015b et antrieur
            obj.val_mat = double(im2bw(obj.val_mat/obj.valmax,0.5));                            %#ok
         else
            % code pour MATLAB 2016a (9.0) et postrieur
            obj.val_mat = double(imbinarize(obj.val_mat/obj.valmax,0.5)); 
         end
      end
		obj.valmax = 1;
	elseif (nbb <= 16)
		valmax = 2^nbb - 1;
		if obj.val_nb
			obj.val_mat = round(obj.val_mat*valmax/obj.valmax);
		end	
		obj.valmax = valmax;
	else
		if obj.val_nb
			obj.val_mat = obj.val_mat/obj.valmax;
		end	
		obj.valmax = 1;
	end
	obj.ima_nbb = nbb;
end

end % fin nested fonction

%---------------------------------------------------------------------------------------------------

end % fin IsaacROI_adjust en raison des nested fonctions
