function liste = IsaacDir(dirname,type,full,recursif)
% Retourne la liste du contenu du dossier dirname
% NB : liste vide si dossier vide ou inexistant
%
%	- dirname	: nom de dossier dans rpertoire courant ou nom complet
%	- type		: 'f' fichiers, 'r' rpertoires, 'x' fichiers et rpertoires
%	- full		: true  = noms complets, false = noms courts (avec extension)
%	- recursif  : true si recursif en profondeur
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

if (type ~= 'f') && (type ~= 'd') && (type ~= 'x')
	error('argument incorrect')
end	

liste = {};
d = dir(dirname);
l = length(d);
j = 0;
for i = 1:l
	if d(i).isdir
		if ~DException(d(i).name)
			if (type ~= 'f')
				j = j + 1;
				% cell array of string
				if full
					liste{j} = fullfile(dirname,d(i).name);                                          %#ok
				else
					liste{j} = d(i).name;                                                            %#ok                      
				end	
			end
			if recursif
				liste2 = IsaacDir(fullfile(dirname,d(i).name),type,full,recursif);
				% transpose pour liste en colonnes 
            liste = [liste,liste2'];                                                            %#ok                     
				j = j + length(liste2);
			end
		end	
	elseif ((type ~= 'd') && ~FException(d(i).name))
		j = j + 1;
		% cell array of string
		if full
			liste{j} = fullfile(dirname,d(i).name);                                                %#ok
		else
			liste{j} = d(i).name;                                                                  %#ok
		end	
	end    
end
liste = liste'; % transpose pour liste en lignes                                               %#ok

%---------------------------------------------------------------------------------------------------

function r = FException(name)

% les fichiers suivants ne doivent pas tre lists :
%   - fichiers cachs du type .DS_Store ou .quelquechose
%   - fichier cach Icon (avec caractre retour chariot  la fin)

r = name(1) == '.' || strcmp(['Icon',char(13)],name);

%---------------------------------------------------------------------------------------------------

function r = DException(name)

% les dossiers suivants ne doivent pas tre lists :
%   - dossiers cachs du type .Trash ou .quelquechose

r = name(1) == '.';
