function filename2 = IsaacFileName(varargin)
% Retourne un nom de fichier du type [str1]filename[str2].ext
% avec longueur ventuellement rduite en privilgiant str1 puis str2 puis filename
%
%	filename2 = IsaacFileName(filename) 
%	filename2 = IsaacFileName(filename,str2)
%	filename2 = IsaacFileName(str1,filename,str2) 
%
%	- filename  : nom du fichier dans rpertoire courant ou nom complet 
%	- filename2 : nom du fichier dans rpertoire courant ou nom complet 
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

global ISAACCONST

switch nargin
	case 1
		[parentdir,shortfilename,ext] = fileparts(varargin{1});
		filename2 = [shortfilename,ext];
		% ajustement de la longueur du nom
		delta1 = length(filename2) - ISAACCONST.MaxName;
		if delta1 > 0
			filename2 = [shortfilename(1:end-delta1-3),'...',ext];
			% 3 = length('...')
		end
	case 2
		[parentdir,shortfilename,ext] = fileparts(varargin{1});
		str2 = varargin{2};
		filename2 = [shortfilename,str2,ext];
		% ajustement de la longueur du nom
		delta1 = length(filename2) - ISAACCONST.MaxName;
		if delta1 > 0
			delta2 = 4 + length(str2) + length(ext) - ISAACCONST.MaxName;
			% 4 = length(shortfilename(1) + '...')
			if delta2 >= 0
				filename2 = [shortfilename(1),'...',str2(1+delta2:end),ext];
			else
				filename2 = [shortfilename(1:1-delta2),'...',str2,ext];
			end	
		end
	case 3
		[parentdir,shortfilename,ext] = fileparts(varargin{2});
		str1 = varargin{1};
		str2 = varargin{3};
		filename2 = [str1,shortfilename,str2,ext];
		% ajustement de la longueur du nom
		delta1 = length(filename2) - ISAACCONST.MaxName;
		if delta1 > 0
			delta2 = length(str1) + 3 + length(str2) + length(ext) - ISAACCONST.MaxName; 
			% 3 = length('...')
			if delta2 >= 0
				delta3 = length(str1) + 3 + length(ext) - ISAACCONST.MaxName;
				if delta3 >= 0			
					filename2 = [str1(1:end-delta3),'...',ext];
				else
					filename2 = [str1,'...',str2(end+1+delta3:end),ext];
				end			
			else
				filename2 = [str1,shortfilename(1:-delta2),'...',str2,ext];	
			end	
		end
	otherwise
		error('nombre d''arguments incorrect')
end
filename2 = fullfile(parentdir,filename2); % gre parentdir = '' ou '/'
