function IsaacModuleReload()
% Reset de la liste des modules et algorithmes enregistrs
% Les doublons de mme nom ne sont pas ajouts
% Les modules par dfaut et modules du rpertoire utilisateur sont rechargs avec priorit
% aux modules par dfaut en cas de doublon
%
% (Appeler en TRY-CATCH pour sortie en erreur d'execution) 
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

global ISAACPRIV
global ISAACCONST
global ISAACPREF

% Tableau des modules (l'ordre des ajouts dtermine la priorit en cas de doublons)
ISAACPRIV.NbMod = 0;
ISAACPRIV.TabMod = [];
AddModules(ISAACCONST.ModsDir)
AddModules(ISAACPREF.UserModsDir)

%---------------------------------------------------------------------------------------------------

function AddModules(dirname)
% Enregistre des modules et algorithmes prsents dans le dossier dirname
% Les doublons de mme nom ne sont pas ajouts
%  1) dirname/Algorithmes/ et dirname/Algorithmes/A_.../ 
%	2) dirname/Mod_.../ et dirname/Mod_.../M_.../  

% Ajout des Algorithmes
rep1 = fullfile(dirname,'Algorithmes');
if exist(rep1,'dir')
	d1 = dir(rep1);
	l1 = length(d1);
	for i = 1:l1
		if (d1(i).isdir && strncmp(d1(i).name,'A_',2))
			rep2 = fullfile(rep1,d1(i).name);
			d2 = dir(rep2);
			l2 = length(d2);
			for j = 1:l2
				AddItem(d2(j),rep2,true);
			end
		else
			AddItem(d1(i),rep1,true);
		end	
	end
end
% Ajout des Modules
d1 = dir(dirname); % d = 0x1 struct array si dirname non existant
l1 = length(d1);
for i = 1:l1
	if (d1(i).isdir && strncmp(d1(i).name,'Mod_',4))
		rep2 = fullfile(dirname,d1(i).name);
		d2 = dir(rep2);
		l2 = length(d2);
		for j = 1:l2
			if (d2(j).isdir && strncmp(d2(j).name,'M_',2))
				rep3 = fullfile(rep2,d2(j).name);
				d3 = dir(rep3);
				l3 = length(d3);
				for k = 1:l3
					AddItem(d3(k),rep3,false);
				end
			else
				AddItem(d2(j),rep2,false);
			end	
		end
	end
end

%---------------------------------------------------------------------------------------------------

function AddItem(item,dirname,isalgo)

global ISAACPRIV

% controle du .m ou .p terminal pour filtrer les fichiers indsirables type .DS_Store
if (~item.isdir && ...
	(strncmp(item.name(end-1:end),'.m',2) || ...
	strncmp(item.name(end-1:end),'.p',2)))
	% suppression du .m ou .p terminal
	name = item.name(1:end-2);
	% ajout dans le tableau des modules avec avertissement si doublons
	if (ISAACPRIV.NbMod && ismember(name,{ISAACPRIV.TabMod.filename}))
	   IsaacMessageWarning(['il dj un module de nom "',name,'"'], ...
		   [IsaacPathStr(fullfile(dirname,item.name),4),' ignor'])
	   return
	end 
	ISAACPRIV.NbMod = ISAACPRIV.NbMod + 1;
	ISAACPRIV.TabMod(ISAACPRIV.NbMod).filename = name;
	ISAACPRIV.TabMod(ISAACPRIV.NbMod).dirname = dirname;
	ISAACPRIV.TabMod(ISAACPRIV.NbMod).isalgo = isalgo;
end
