function [etiq,nbetiq] = IsaacECCD(histo,dist)
% Etiquetage en composantes connexes diffuses d'un histogramme compact nD
% 
% Usage [etiq,nbetiq] = IsaacECCD(histo,dist)
% 
% 	histo	: matrice histogramme compact nD
% 	dist	: distance de Chebychev dfinissant le voisinage
% 	etiq	: vecteur colonne des tiquettes de composantes connexes				
% 	nbetiq	: nombre de composantes connexes
% 
% 	histo, dist, etiq et nbetiq de type double
% 	
% D'aprs la thse de Si Ouattara (Universit d'Angers - dcembre 2009)
% et J.P. Cocquerez, S. Philipp. "Analyse d'images : filtrage et segmentation", Masson, 1995 
%
% Algorithm for OpenIsaac
% version 1
%  2011-2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

if ismac  
	if verLessThan('matlab', '9.3') 
      % MATLAB 2017a et antrieur
      [etiq,nbetiq] = eccd_mac2010b(histo,dist);
   else
      % MATLAB 2017b (9.3) et postrieur
      [etiq,nbetiq] = eccd_mac2017b(histo,dist);
	end   
elseif ispc
	if verLessThan('matlab', '9.3') 
      % MATLAB 2017a et antrieur
      [etiq,nbetiq] = eccd_win2013b(histo,dist);
   else
      % MATLAB 2017b (9.3) et postrieur
      [etiq,nbetiq] = eccd_win2017b(histo,dist);
	end   
else
    error('mexfile inexistant')     
end
end
