function EcolEdit()
% Editeur de @IsaacECOL
%
% Tool for OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

% structure ud : champ UserData
%	ToolDir		: rpertoire de l'outil
%	PTarget		: 1 = image cible, 2 = mmoire, 3 = fichier, 4  = MATLAB base workspace
%	PVarName    : nom de la variable associe au paramtre dit
%	Param       : objet @IsaacECOL
%	IsICC       : true si profil ICC, false sinon (profil prdfini)

%---------------------------------------------------------------------------------------------------

global ISAACINFO

% si EcolEdit est dja lanc, l'ammener au premier plan.
h = findobj(allchild(0),'flat','Tag','EcolEdit');
if ~isempty(h)
	figure(h(1)) % mise au 1er plan
   return
end

hauteurfig = 280;
% figure(position selon ISAACINFO.DefPos)
h0 = figure( ...
	'CloseRequestFcn','EcolEdit_cb CloseBox', ...
	'Name','EcolEdit', ...
	'Position',IsaacFenPos(ISAACINFO.DefPos(1),ISAACINFO.DefPos(2),290,hauteurfig,0), ...
	'Tag','EcolEdit');

IsaacDefaultProperties(h0)

% text Ecol	 ---------------------------------------------------------------------------------------
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'FontAngle','italic', ...
	'HorizontalAlignment','left', ...
	'Position',[5 hauteurfig - 20 45 15], ...
	'String','ECOL', ...
	'Style','text');
% Boutons radio "Prdfini/ICC"
uicontrol('Parent',h0, ...
	'Callback','EcolEdit_cb RadButPredef', ...
	'String','Prdfini', ...
	'Style','radiobutton', ...
	'Position',[75 hauteurfig - 20 80 15], ...
	'Tag','RadButPredef');
uicontrol('Parent',h0, ...
	'Callback','EcolEdit_cb RadButICC', ...
	'String','ICC', ...
	'Style','radiobutton', ...
	'Position',[160 hauteurfig - 20 80 15], ...
	'Tag','RadButICC');
% Sparateur ---------------------------------------------------------------------------------------
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'Position',[0 hauteurfig - 27 290 1], ...
	'Style','frame');
% text Type
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'HorizontalAlignment','left', ...
	'Position',[5 hauteurfig - 51 60 15], ...
	'String','Type :', ...
	'Style','text');
% popup Type
uicontrol('Parent',h0, ...
	'Callback','EcolEdit_cb PopupType', ...
	'Position',[75 hauteurfig - 50 210 16], ...
	'Style','popupmenu', ...
	'Tag','PopupType');
% text Illuminant
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'HorizontalAlignment','left', ...
	'Position',[5 hauteurfig - 75 60 15], ...
	'String','Illuminant :', ...
	'Style','text');
% popup Illuminant
uicontrol('Parent',h0, ...
	'Callback','EcolEdit_cb PopupIlluminant', ...
	'Position',[75 hauteurfig - 75 210 16], ...
	'Style','popupmenu', ...
	'Tag','PopupIlluminant');
% text PointBlanc
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'HorizontalAlignment','left', ...
	'Position',[5 hauteurfig - 100 60 15], ...
	'String','Point Blanc :', ...
	'Style','text');
% text PointBlanc val
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[75 hauteurfig - 100 205 15], ...
	'Style','text', ...
	'Tag','StxtPointBlancVal');
% text Dimension
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'HorizontalAlignment','left', ...
	'Position',[5 hauteurfig - 120 60 15], ...
	'String','Dimension :', ...
	'Style','text');
% text Dimension val
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[75 hauteurfig - 120 50 15], ...
	'Style','text', ...
	'Tag','StxtDimensionVal');
% text NbBits
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'HorizontalAlignment','left', ...
	'Position',[135 hauteurfig - 120 40 15], ...
	'String','Nb bits :', ...
	'Style','text');
% text NbBits val
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[180 hauteurfig - 120 100 15], ...
	'Style','text', ...
	'Tag','StxtNbBitsVal');
% text Gamma
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'HorizontalAlignment','left', ...
	'Position',[5 hauteurfig - 144 60 15], ...
	'String','Gamma :', ...
	'Style','text');
% Bouton Gamma-	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','EcolEdit_cb ButGamma-', ...
	'Position',[75 hauteurfig - 145 16 16], ...
	'String','-', ...
	'Tag','ButGamma-');
% Bouton GammaR
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','EcolEdit_cb ButGammaR', ...
	'Position',[93 hauteurfig - 145 16 16], ...
	'String','R', ...
	'Tag','ButGammaR');
% Bouton Gamma+	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','EcolEdit_cb ButGamma+', ...
	'Position',[111 hauteurfig - 145 16 16], ...
	'String','+', ...
	'Tag','ButGamma+');
% Texte GammaVal	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[135 hauteurfig - 144 145 15], ...
	'Style','text', ...
	'Tag','StxtGammaVal');
% Sparateur ---------------------------------------------------------------------------------------
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'Position',[0 hauteurfig - 152 290 1], ...
	'Style','frame');
% text TargetInfo  	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[5 hauteurfig - 172 280 15], ...
	'Style','text', ...
	'Tag','StxtTargetInfo');
% Bouton radio Param image cible
uicontrol('Parent',h0, ...
	'Callback','EcolEdit_cb RadButParamCible', ...
	'String','Image cible', ...
	'Style','radiobutton', ...
	'Position',[5 hauteurfig - 205 190 15], ...
	'Tag','RadButParamCible');
% Bouton radio Param mmoire
uicontrol('Parent',h0, ...
	'Callback','EcolEdit_cb RadButParamMem', ...
	'String','Mmoire', ...
	'Style','radiobutton', ...
	'Position',[5 hauteurfig - 225 100 15], ...
	'Tag','RadButParamMem');
% Bouton radio Param fichier
uicontrol('Parent',h0, ...
	'Callback','EcolEdit_cb RadButParamFich', ...
	'String','Fichier', ...
	'Style','radiobutton', ...
	'Position',[5 hauteurfig - 245 100 15], ...
	'Tag','RadButParamFich');
% Bouton radio Param MATLAB
uicontrol('Parent',h0, ...
	'Callback','EcolEdit_cb RadButParamMATLAB', ...
	'String','MATLAB', ...
	'Style','radiobutton', ...
	'Position',[5 hauteurfig - 265 100 15], ...
	'Tag','RadButParamMATLAB');
% edit Varname	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Callback','EcolEdit_cb EtxtVarname', ...
	'FontSize',ISAACINFO.FontSize, ...
	'Position',[90 hauteurfig - 268 80 22], ...
	'Style','edit', ...
	'Tag','EtxtVarname');
% bouton ParamPull
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','EcolEdit_cb ButParamPull', ...
	'Position',[195 hauteurfig - 200 90 20], ...
	'String','Importer', ...
	'Tag','ButParamPull');
% bouton ParamPush
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','EcolEdit_cb ButParamPush', ...
	'Position',[195 hauteurfig - 225 90 20], ...
	'String','Appliquer', ...
	'Tag','ButParamPush');
% bouton Convertir
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','EcolEdit_cb ButConvertir', ...
	'Position',[195 hauteurfig - 250 90 20], ...
	'String','Convertir', ...
	'Tag','ButConvertir');
% bouton Supprimer
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','EcolEdit_cb ButSupprimer', ...
	'Position',[195 hauteurfig - 275 90 20], ...
	'String','Supprimer', ...
	'Tag','ButSupprimer');

%---------------------------------------------------------------------------------------------------

% Initialisation

ud.ToolDir = fileparts(mfilename('fullpath'));
ud.PTarget = 1; % image cible
ud.IsICC = false;
ud.PVarName = 'x';
set(findobj(h0,'Tag','EtxtVarname'),'String',ud.PVarName,'Visible','off')
set(findobj(h0,'Tag','RadButParamCible'),'Value',1)
set(findobj(h0,'Tag','RadButPredef'),'Value',1)
ud = EcolEdit_maj(h0,ud,'Popups','Valeurs','Boutons');
set(h0,'UserData',ud);
addpath(ud.ToolDir)
IsaacEventUpdListe(h0,ud.ToolDir,'EcolEdit_upd') % abonnement aux vnements
cible = IsaacImageCible;
if isempty(cible)
	EcolEdit_upd(h0,1,cible,NaN)
else
	EcolEdit_upd(h0,2,cible,NaN)
end
% auteur = NaN car n'accepte pas les vnements causs par soi-mme pour mise  jour graphique