function ud = EcolEdit_maj(fighnd,ud,varargin)
% Mise  jour de l'affichage dans EcolEdit
% (partag par EcolEdit et EcolEdit_cb)
%
%	ud = EcolEdit_maj(fighnd,ud,maj1,...,majN)
%
% - fighnd	: handle figure EcolEdit
% - ud		: champ UserData de EcolEdit
%
%	propname			
%	--------
%	'Boutons'	: maj des boutons
%	'Popups'	: maj des popups menus
%	'Valeurs'	: maj des valeurs affiches
%
% Tool for OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

global ISAACINFO

if (nargin < 3)
	error('nombre d''arguments incorrect')
end
propargin = varargin;
while ~isempty(propargin)
	propname = propargin{1};
	propargin = propargin(2:end);
	switch propname
		case 'Boutons'
			MajBoutons
		case 'Popups'
			MajPopups
		case 'Valeurs'
			MajValues
		otherwise
			error('argument incorrect')
	end
end
	
% --- Nested fonction ------------------------------------------------------------------------------

function MajPopups
	
if ud.IsICC
	s1 = IsaacDir(ISAACINFO.ProfilsDir,'f',false,false);
	n = size(s1,1);
	if ~n
		ud.Param = [];
		set(findobj(fighnd,'Tag','PopupType'),'Enable','inactive', ...
			'ForegroundColor',ISAACINFO.TextColor3,'String','Aucun profil ICC','Value',1)
		% popup string = 1 espace (et pas '') sinon le popup ne s'affiche pas
		set(findobj(fighnd,'Tag','PopupIlluminant'),'Enable','off','String',' ','Value',1)
	else	
		ok = false;
		for i = 1:n
			try
				ud.Param = IsaacECOL('ICC',s1{i});
				ok = true;
				break
			catch
				IsaacMessageWarning(['fichier profil ICC ',s1{i},' invalide'])
			end	
		end
		if (i > 1)
			s1(1:i-1) = [];
		end
		if ok		
			set(findobj(fighnd,'Tag','PopupType'),'Enable','on', ...
				'ForegroundColor',ISAACINFO.TextColor1,'String',s1,'Value',1)
			s2 = IsaacECOL_get(ud.Param,'LightSourcesValues'); 
			set(findobj(fighnd,'Tag','PopupIlluminant'),'Enable','on','String',s2,'Value',1)
		else
			ud.Param = [];
			set(findobj(fighnd,'Tag','PopupType'),'Enable','inactive', ...
				'ForegroundColor',ISAACINFO.TextColor3,'String','Aucun profil ICC valide','Value',1)
			% popup string = 1 espace (et pas '') sinon le popup ne s'affiche pas
			set(findobj(fighnd,'Tag','PopupIlluminant'),'Enable','off','String',' ','Value',1)
		end	
	end
else
	objECOL = IsaacECOL(); % profil par dfaut non ICC
	s1 = IsaacECOL_get(objECOL,'NamesValues');
	s2 = IsaacECOL_get(objECOL,'LightSourcesValues');
	try
		ud.Param = IsaacECOL(s1{1},s2{1});
	catch exception
		IsaacMessageErreur(IsaacError(exception))
		return
	end
	set(findobj(fighnd,'Tag','PopupType'),'Enable','on', ...
		'ForegroundColor',ISAACINFO.TextColor1,'String',s1,'Value',1)
	set(findobj(fighnd,'Tag','PopupIlluminant'),'Enable','on','String',s2,'Value',1)
end

end % fin nested fonction

% --- Nested fonction ------------------------------------------------------------------------------

function MajValues

if isempty(ud.Param)
	set(findobj(fighnd,'Tag','StxtPointBlancVal'),'String','')
	set(findobj(fighnd,'Tag','StxtDimensionVal'),'String','')
	set(findobj(fighnd,'Tag','StxtNbBitsVal'),'String','')
	set(findobj(fighnd,'Tag','StxtGammaVal'),'String','')
else
	wp = IsaacECOL_get(ud.Param,'WhitePoint');
	if isempty(wp)
		s = 'inconnu';
	else	
		s = ['[ ',num2str(wp(1),'%6.4f')];
		for i = 2:size(wp,2)
			s = [s,' , ',num2str(wp(i),'%8.4f')];																	%#ok
		end	
		s = [s,' ]'];
	end	
	set(findobj(fighnd,'Tag','StxtPointBlancVal'),'String',s)
	dim = IsaacECOL_get(ud.Param,'Dimension');
	if dim
		s = num2str(dim);
	else
		s = '?';
	end	
	set(findobj(fighnd,'Tag','StxtDimensionVal'),'String',s)
	bc = IsaacECOL_get(ud.Param,'BitClass');
	s = num2str(bc(1));
	for i = 2:length(bc)
		s = [s,' / ',num2str(bc(i))];																					%#ok
	end	
	set(findobj(fighnd,'Tag','StxtNbBitsVal'),'String',s)
	s = num2str(IsaacECOL_get(ud.Param,'Gamma'),'%.1f');
	set(findobj(fighnd,'Tag','StxtGammaVal'),'String',s)
end	

end % fin nested fonction

% --- Nested fonction ------------------------------------------------------------------------------

function MajBoutons

if isempty(ud.Param)
	set(findobj(fighnd,'Tag','ButGamma-'),'Enable','off')
	set(findobj(fighnd,'Tag','ButGammaR'),'Enable','off')
	set(findobj(fighnd,'Tag','ButGamma+'),'Enable','off')
	set(findobj(fighnd,'Tag','ButParamPush'),'Enable','off')
	if (ud.PTarget == 1)
		set(findobj(fighnd,'Tag','ButConvertir'),'Enable','off')
	end
else
	set(findobj(fighnd,'Tag','ButGamma-'),'Enable','on')
	set(findobj(fighnd,'Tag','ButGammaR'),'Enable','on')
	set(findobj(fighnd,'Tag','ButGamma+'),'Enable','on')
	set(findobj(fighnd,'Tag','ButParamPush'),'Enable','on')
	if (ud.PTarget == 1)
		cible = IsaacImageCible;
		if ~ isempty(cible) && IsaacImage_get(cible,'IsColorSpace')
			set(findobj(fighnd,'Tag','ButConvertir'),'Enable','on')
		end
	end	
end	

end % fin nested fonction

%---------------------------------------------------------------------------------------------------

end % fin EcolEdit_maj en raison des nested fonctions
