function HistoEdit()
% Editeur de @IsaacHISTO
%
% Tool for OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
% Contributor: Clment Bourgeais (2018)
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

% structure ud : champ UserData
%	ToolDir			: rpertoire de l'outil
%	PTarget			: 1 = image cible, 2 = mmoire, 3 = fichier, 4  = MATLAB base workspace
%	Param          : objet @IsaacHISTO
%	PVarName       : nom de la variable associe au paramtre dit
%	AxHisto			: handle axe histogramme
%	AxColorbar		: handle axe colorbar des effectifs
%	AxTick1			: matrice tiquettes axes version longue (1D)
%	AxTick2			: matrice tiquettes axes version courte (2D et 3D)
%	AxXmin			: min axe
%	Axmax          : max axe
%	HistoInfoHnd	: handle liste affichage HistoInfo
%	FormatStr		: format d'affichage des valeurs de HistoInfo
%	NbPlans			: nombre de plans possibles dans l'histogramme
%	AffDim			: dimension	affiche
%	AffPlans       : matrice(1,p) des plans affichs
%	PlansStr       : cell array of string des popup de plans
%	ShowGraph		: true si affiche histo des plans, false pour description texte
%	IsRoi          : false|true si effectif ROI non nul
% 	AffRoi			: 0 (non) | 1 (oui) | 2 (voir)
%	IsRoiMark		: false|true si valeurs ROI marques sur toute la hauteur du graphe
%	HistoROI       : objet @IsaacHISTO limit  la ROI de l'image ou [] si non calcul
%	HistoCopy		: objet @IsaacHISTO mmoris pour PTarget = mmoire ou fichier
%	VisMin			: min affich de l'effectif
%	VisMax			: max affich de l'effectif
%	AZ             : azimuth (vue 3D)
%	EL             : levation (vue 3D)
%	BigDot        	: false|true si affichage avec "gros" traits ou points
%	TabSeuil       : tableau des intervalles de couleur en effectif (vue 3D)
%	TabColor       : tableau des couleurs associes aux intervalles (vue 3D)
%	NbColor			: nb de couleurs pour reprsenter les effectifs (vue 3D)

%---------------------------------------------------------------------------------------------------

global ISAACINFO

% si HistoEdit est dja lanc, l'ammener au premier plan.
h = findobj(allchild(0),'flat','Tag','HistoEdit');
if ~isempty(h)
	figure(h(1)) % mise au 1er plan
   return
end

hauteurfig = 430;
% figure(position selon ISAACINFO.DefPos)
h0 = figure( ...
	'CloseRequestFcn','HistoEdit_cb CloseBox', ...
	'Name','HistoEdit', ...
	'Position',IsaacFenPos(ISAACINFO.DefPos(1),ISAACINFO.DefPos(2),640,hauteurfig,0), ...
	'Tag','HistoEdit');
	
IsaacDefaultProperties(h0)

% sparateur vertical
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'Position',[270 0 1 hauteurfig], ...
	'Style','frame');
% text ParamInfo -----------------------------------------------------------------------------------	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[0 hauteurfig - 15 270 15], ...
	'Style','text', ...
	'Tag','StxtParamInfo');
% Texte Plans	
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'Position',[0 hauteurfig - 35 270 15], ...
	'String','Dim                1D                2D                  3D', ...
	'Style','text');
% Popup des plans
uicontrol('Parent',h0, ...
	'Callback','HistoEdit_cb PopupDim', ...
	'Position',[5 hauteurfig - 55 65 16], ...
	'Style','popupmenu', ...
	'Tag','PopupDim');
uicontrol('Parent',h0, ...
	'Callback','HistoEdit_cb PopupPlan1', ...
	'Position',[70 hauteurfig - 55 65 16], ...
	'Style','popupmenu', ...
	'Tag','PopupPlan1');
uicontrol('Parent',h0, ...
	'Callback','HistoEdit_cb PopupPlan2', ...
	'Position',[135 hauteurfig - 55 65 16], ...
	'Style','popupmenu', ...
	'Tag','PopupPlan2');
uicontrol('Parent',h0, ...
	'Callback','HistoEdit_cb PopupPlan3', ...
	'Position',[200 hauteurfig - 55 65 16], ...
	'Style','popupmenu', ...
	'Tag','PopupPlan3');
% Radiobouton ShowGraph
uicontrol('Parent',h0, ...
	'Callback','HistoEdit_cb RadShowGraph', ...
	'String','Graphe', ...
	'Style','radiobutton', ...
	'Position',[50 hauteurfig - 82 80 15], ...
	'Tag','RadShowGraph');
% Radiobouton ShowInfos	
uicontrol('Parent',h0, ...
	'Callback','HistoEdit_cb RadShowInfos', ...
	'String','Description', ...
	'Style','radiobutton', ...
	'Position',[140 hauteurfig - 82 80 15], ...
	'Tag','RadShowInfos');
% Sparateur
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.TextColor1, ...
	'Enable','inactive', ...
	'Position',[0 hauteurfig - 90 270 1], ...
	'Style','frame');
% text Effectifs
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor1, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'Position',[0 hauteurfig - 110 270 15], ...
	'String','Effectifs', ...
	'Style','text');
% text EffMinVal	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[20 hauteurfig - 130 65 15], ...
	'Style','text', ...
	'Tag','StxtEffMin');
% text EffMaxVal	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[105 hauteurfig - 130 65 15], ...
	'Style','text', ...
	'Tag','StxtEffMax');
% text EffTotal	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[190 hauteurfig - 130 65 15], ...
	'Style','text', ...
	'Tag','StxtEffTotal');
% text effectifs lgende
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor1, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'Position',[0 hauteurfig - 150 270 15], ...
	'String','Min                  Max                  Total', ...
	'Style','text');
% text Effectifs affichs
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor1, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'Position',[0 hauteurfig - 170 270 15], ...
	'String','Effectifs affichs', ...
	'Style','text');
% edit EffVisMin
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Callback','HistoEdit_cb EtxtEffVisMin', ...
	'FontSize',ISAACINFO.FontSize, ...
	'Position',[40 hauteurfig - 195 70 22], ...
	'Style','edit', ...
	'Tag','EtxtEffVisMin');
% edit EffVisMax
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Callback','HistoEdit_cb EtxtEffVisMax', ...
	'FontSize',ISAACINFO.FontSize, ...
	'Position',[155 hauteurfig - 195 70 22], ...
	'Style','edit', ...
	'Tag','EtxtEffVisMax');
% text EffVisMinMax
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor1, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'Position',[0 hauteurfig - 215 270 15], ...
	'String','Min                               Max', ...
	'Style','text');
% Sparateur
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.TextColor1, ...
	'Enable','inactive', ...
	'Position',[0 hauteurfig - 220 270 1], ...
	'Style','frame');
% Texte ROI	
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'Position',[0 hauteurfig - 240 270 15], ...
	'String','ROI', ...
	'Style','text');
% Radioboutons ROI
uicontrol('Parent',h0, ...
	'Callback','HistoEdit_cb RadRoiNon', ...
	'String','Non', ...
	'Style','radiobutton', ...
	'Position',[30 hauteurfig - 257 50 15], ...
	'Tag','RadRoiNon');
uicontrol('Parent',h0, ...
	'Callback','HistoEdit_cb RadRoiOui', ...
	'String','Oui', ...
	'Style','radiobutton', ...
	'Position',[90 hauteurfig - 257 50 15], ...
	'Tag','RadRoiOui');
uicontrol('Parent',h0, ...
	'Callback','HistoEdit_cb RadRoiVoir', ...
	'String','Voir', ...
	'Style','radiobutton', ...
	'Position',[150 hauteurfig - 257 50 15], ...
	'Tag','RadRoiVoir');
% checkbox RoiMark	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor1, ...
	'Callback','HistoEdit_cb ChkRoiMark', ...
	'Position',[210 hauteurfig - 257 30 18], ...
	'String','|', ...
	'Style','checkbox', ...
	'Tag','ChkRoiMark');
% Sparateur
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.TextColor1, ...
	'Enable','inactive', ...
	'Position',[0 hauteurfig - 265 270 1], ...
	'Style','frame');
% text Oprations
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'Position',[0 hauteurfig - 285 270 15], ...
	'String','Oprations mmoire', ...
	'Style','text');
% bouton Union
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','HistoEdit_cb ButUnion', ...
	'Position',[15 hauteurfig - 310 75 20], ...
	'String','Union', ...
	'Tag','ButUnion');
% bouton Intersection
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','HistoEdit_cb ButIntersect', ...
	'Position',[100 hauteurfig - 310 75 20], ...
	'String','Intersection', ...
	'Tag','ButIntersect');
% bouton Diffrence
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','HistoEdit_cb ButDiffer', ...
	'Position',[185 hauteurfig - 310 75 20], ...
	'String','Diffrence', ...
	'Tag','ButDiffer');
% Sparateur
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.TextColor1, ...
	'Enable','inactive', ...
	'Position',[0 hauteurfig - 315 270 1], ...
	'Style','frame');
% text TargetInfo  ---------------------------------------------------------------------------------	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[5 hauteurfig - 335 260 15], ...
	'Style','text', ...
	'Tag','StxtTargetInfo');
% Bouton radio Param image cible
uicontrol('Parent',h0, ...
	'Callback','HistoEdit_cb RadButParamCible', ...
	'String','Image cible', ...
	'Style','radiobutton', ...
	'Position',[5 hauteurfig - 360 100 15], ...
	'Tag','RadButParamCible');
% Bouton radio Param mmoire
uicontrol('Parent',h0, ...
	'Callback','HistoEdit_cb RadButParamMem', ...
	'String','Mmoire', ...
	'Style','radiobutton', ...
	'Position',[5 hauteurfig - 380 100 15], ...
	'Tag','RadButParamMem');
% Bouton radio Param fichier
uicontrol('Parent',h0, ...
	'Callback','HistoEdit_cb RadButParamFich', ...
	'String','Fichier', ...
	'Style','radiobutton', ...
	'Position',[5 hauteurfig - 400 100 15], ...
	'Tag','RadButParamFich');
% Bouton radio Param MATLAB
uicontrol('Parent',h0, ...
	'Callback','HistoEdit_cb RadButParamMATLAB', ...
	'String','MATLAB', ...
	'Style','radiobutton', ...
	'Position',[5 hauteurfig - 420 100 15], ...
	'Tag','RadButParamMATLAB');
% edit Varname	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Callback','HistoEdit_cb EtxtVarname', ...
	'FontSize',ISAACINFO.FontSize, ...
	'Position',[85 hauteurfig - 424 80 22], ...
	'Style','edit', ...
	'Tag','EtxtVarname');
% bouton ParamPull
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','HistoEdit_cb ButParamPull', ...
	'Position',[170 hauteurfig - 365 90 20], ...
	'Tag','ButParamPull');
% bouton ParamPush
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','HistoEdit_cb ButParamPush', ...
	'Position',[170 hauteurfig - 390 90 20], ...
	'Tag','ButParamPush');
% Axe HistoEdit ------------------------------------------------------------------------------------
ud.AxHisto = axes('Parent',h0, ...
	'Position',[325 hauteurfig - 290 266 266], ...
	'Visible','off');
% Colorbar
% 'HandleVisibility' = 'off' pour ne pas rendre l'axe cliquable 
ud.AxColorbar = axes('Parent',h0, ...
   'HandleVisibility','off', ...
   'Position',[329 hauteurfig - 360 256 10], ...
	'Visible','off', ...
	'Ytick',[]);
image('Parent',ud.AxColorbar, ...
	'CDataMapping','scaled', ...
	'Clipping','on', ...
	'Visible','off');
% liste HistoInfo
ud.HistoInfoHnd = uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontName','Monospaced', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'HorizontalAlignment','left', ...
	'SelectionHighlight','off', ...
	'Position',[325 hauteurfig - 300 266 266], ...
	'Style','listbox', ...
	'Tag','ListHistoInfo', ...
	'Value',1, ...
	'Visible','off');
% Sparateur
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.TextColor1, ...
	'Enable','inactive', ...
	'Position',[270 hauteurfig - 395 370 1], ...
	'Style','frame');
% text Vue 3D 
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor1, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'Position',[285 hauteurfig - 420 50 15], ...
	'String','Vue 3D :', ...
	'Style','text');
% Bouton HistG	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','HistoEdit_cb ButHistG', ...
	'Position',[339 hauteurfig - 421 16 16], ...
	'String','<', ...
	'Tag','ButHistG');
% Bouton HistB	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','HistoEdit_cb ButHistB', ...
	'Position',[357 hauteurfig - 421 16 16], ...
	'String','-', ...
	'Tag','ButHistB');
% Bouton HistC	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','HistoEdit_cb ButHistC', ...
	'Position',[375 hauteurfig - 421 16 16], ...
	'String','0', ...
	'Tag','ButHistC');
% Bouton HistH	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','HistoEdit_cb ButHistH', ...
	'Position',[393 hauteurfig - 421 16 16], ...
	'String','+', ...
	'Tag','ButHistH');
% Bouton HistD	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','HistoEdit_cb ButHistD', ...
	'Position',[411 hauteurfig - 421 16 16], ...
	'String','>', ...
	'Tag','ButHistD');
% checkbox BigDot	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor1, ...
	'Callback','HistoEdit_cb ChkBigDot', ...
	'Position',[455 hauteurfig - 422 60 18], ...
	'String','Gras', ...
	'Style','checkbox', ...
	'Tag','ChkBigDot');
% Bouton Image histo
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','HistoEdit_cb ButScreenCopy', ...
	'Position',[535 hauteurfig - 422 100 20], ...
	'String','Image histo', ...
	'Tag','ButScreenCopy');
%---------------------------------------------------------------------------------------------------

% Initialisation

ud.ToolDir = fileparts(mfilename('fullpath'));
ud.PTarget = 1; % image cible
ud.Param = [];
ud.PVarName = 'x';
ud.AffDim = 1;
ud.AffPlans = 1;
ud.ShowGraph = true;
ud.AffRoi = 0;
ud.IsRoiMark = false;
ud.HistoROI = [];
ud.HistoCopy = [];
ud.AZ = -20;
ud.EL = 30;
ud.BigDot = false;
set(h0,'UserData',ud);
set(findobj(h0,'Tag','EtxtVarname'),'String',ud.PVarName,'Visible','off')
set(findobj(h0,'Tag','RadButParamCible'),'Value',1)
set(findobj(h0,'Tag','ButParamPull'),'Visible','off')
set(findobj(h0,'Tag','ButParamPush'),'Visible','off')
set(findobj(h0,'Tag','ButUnion'),'Enable','off')
set(findobj(h0,'Tag','ButIntersect'),'Enable','off')
set(findobj(h0,'Tag','ButDiffer'),'Enable','off')
addpath(ud.ToolDir)
IsaacEventUpdListe(h0,ud.ToolDir,'HistoEdit_upd') % abonnement aux vnements
cible = IsaacImageCible;
if isempty(cible)
	HistoEdit_upd(h0,1,cible,NaN)
else
	HistoEdit_upd(h0,2,cible,NaN)
end
% auteur = NaN car n'accepte pas les vnements causs par soi-mme pour mise  jour graphique
