function ImageAjust()
% Ajustement de l'image cible
%
% Tool for OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

% structure ud : champ UserData
%	ToolDir		: rpertoire de l'outil
%	PNBDigits	: nombre de caractres pour afficher ISAACINFO.ImMaxPlans
%	Plan        : plan slectionn
%	DynMin		: valeur min slectionne pour ajustement dynamique entre 0 et 1
%	DynMax		: valeur max slectionne pour ajustement dynamique entre 0 et 1

%---------------------------------------------------------------------------------------------------

global ISAACINFO

% si ImageAjust est dj lanc, l'ammener au premier plan.
h = findobj(allchild(0),'flat','Tag','ImageAjust');
if ~isempty(h)
	figure(h(1)) % mise au 1er plan
   return
end

hauteurfig = 420;
% figure(position selon ISAACINFO.DefPos)
h0 = figure( ...
	'CloseRequestFcn','ImageAjust_cb CloseBox', ...
	'Name','ImageAjust', ...
	'Position',IsaacFenPos(ISAACINFO.DefPos(1),ISAACINFO.DefPos(2),160,hauteurfig,0), ...
	'Tag','ImageAjust');

IsaacDefaultProperties(h0)

% text CibleName	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[0 hauteurfig - 15 160 15], ...
	'Style','text', ...
	'Tag','StxtCibleName');
% text Dimensions
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'Position',[0 hauteurfig - 35 160 15], ...
	'String','Dim X        Dim Y        Dim Z', ...
	'Style','text');
% text DimX val
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[5 hauteurfig - 52 47 15], ...
	'Style','text', ...
	'Tag','StxtDimXVal');
% text DimY val
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[57 hauteurfig - 52 47 15], ...
	'Style','text', ...
	'Tag','StxtDimYVal');
% text DimZ val
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[110 hauteurfig - 52 47 15], ...
	'Style','text', ...
	'Tag','StxtDimZVal');
% sparateur
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.TextColor1, ...
	'Enable','inactive', ...
	'Position',[0 hauteurfig - 60 160 1], ...
	'Style','frame');
% text Dimensions
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'Position',[0 hauteurfig - 80 160 15], ...
	'String','Dimensions', ...
	'Style','text');
% Bouton Resize-	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','ImageAjust_cb ButResize-', ...
	'Position',[5 hauteurfig - 105 40 20], ...
	'String','1/2', ...
	'Tag','ButResize-');
% Bouton Resize+	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','ImageAjust_cb ButResize+', ...
	'Position',[50 hauteurfig - 105 40 20], ...
	'String','1x2', ...
	'Tag','ButResize+');
% Bouton Crop	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','ImageAjust_cb ButCrop', ...
	'Position',[95 hauteurfig - 105 60 20], ...
	'String','Slection', ...
	'Tag','ButCrop');
% text PlansMinMax
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'HorizontalAlignment','left', ...
	'Position',[5 hauteurfig - 125 135 15], ...
	'String','  Plan        Min           Max', ...
	'Style','text');
% Liste Plans
% FontName = Monospaced pour une police non proportionnelle
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'Enable','off', ...
	'FontName','Monospaced', ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[5 hauteurfig - 195 150 70], ...
	'SelectionHighlight','off', ...
	'Style','listbox', ...
	'Tag','ListPlans');
% Bouton PlanDown	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','ImageAjust_cb ButPlanDown', ...
	'Position',[5 hauteurfig - 222 20 20], ...
	'String','-', ...
	'Tag','ButPlanDown');
% Bouton PlanUp	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','ImageAjust_cb ButPlanUp', ...
	'Position',[30 hauteurfig - 222 20 20], ...
	'String','+', ...
	'Tag','ButPlanUp');
% Bouton RemovePlan	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','ImageAjust_cb ButRemovePlan', ...
	'Position',[55 hauteurfig - 222 100 20], ...
	'String','Supprimer plan', ...
	'Tag','ButRemovePlan');
% sparateur
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.TextColor1, ...
	'Enable','inactive', ...
	'Position',[0 hauteurfig - 230 160 1], ...
	'Style','frame');
% text Dynamique
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'Position',[0 hauteurfig - 250 160 15], ...
	'String','Dynamique', ...
	'Style','text');
% text NbBits
uicontrol('Parent',h0, ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'HorizontalAlignment','left', ...
	'Position',[5 hauteurfig - 275 40 15], ...
	'String','Nb bits :', ...
	'Style','text');
% Popup NbBits
uicontrol('Parent',h0, ...
	'Callback','ImageAjust_cb PopupNbBits', ...
	'Position',[45 hauteurfig - 273 65 16], ...
	'Style','popupmenu', ...
	'Tag','PopupNbBits');
% Bouton ChangeDyn	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','ImageAjust_cb ButChangeDyn', ...
	'Position',[115 hauteurfig - 276 40 20], ...
	'String','Dyn', ...
	'Tag','ButChangeDyn');
% text MinMax
uicontrol('Parent',h0, ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'Position',[0 hauteurfig - 300 160 15], ...
	'String','Min                        Max', ...
	'Style','text');
% text EMin val
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[5 hauteurfig - 317 50 15], ...
	'Style','text', ...
	'Tag','StxtEMinVal');
% text EMax val
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor2, ...
	'FontSize',ISAACINFO.FontSize + 1, ...
	'Position',[105 hauteurfig - 317 50 15], ...
	'Style','text', ...
	'Tag','StxtEMaxVal');
% Slider EMin
uicontrol('Parent',h0, ...
	'Callback','ImageAjust_cb SliderEMin', ...
	'Max',1, ...
	'Min',0, ...
	'Position',[5 hauteurfig - 340 150 15], ...
	'Style','slider', ...
	'Tag','SliderEMin');
% Slider EMax
uicontrol('Parent',h0, ...
	'Callback','ImageAjust_cb SliderEMax', ...
	'Max',1, ...
	'Min',0, ...
	'Position',[5 hauteurfig - 360 150 15], ...
	'Style','slider', ...
	'Tag','SliderEMax');
% sparateur
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.TextColor1, ...
	'Enable','inactive', ...
	'Position',[0 hauteurfig - 370 160 1], ...
	'Style','frame');
% text Orientation
uicontrol('Parent',h0, ...
	'Enable','inactive', ...
	'ForegroundColor',ISAACINFO.TextColor2, ...
	'Position',[0 hauteurfig - 390 160 15], ...
	'String','Orientation', ...
	'Style','text');
% Bouton Rot-90	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','ImageAjust_cb ButRot-', ...
	'Position',[5 hauteurfig - 415 30 20], ...
	'String','-90', ...
	'Tag','ButRot-');
% Bouton Rot+90	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','ImageAjust_cb ButRot+', ...
	'Position',[45 hauteurfig - 415 30 20], ...
	'String','+90', ...
	'Tag','ButRot+');
% Bouton MirrorH	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','ImageAjust_cb ButMirrorH', ...
	'Position',[85 hauteurfig - 415 30 20], ...
	'String','||', ...
	'Tag','ButMirrorH');
% Bouton MirrorV	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACINFO.IsaacColor3, ...
	'Callback','ImageAjust_cb BuMirrorV', ...
	'Position',[125 hauteurfig - 415 30 20], ...
	'String','==', ...
	'Tag','ButMirrorV');

%---------------------------------------------------------------------------------------------------

% Initialisation

ud.ToolDir = fileparts(mfilename('fullpath'));
ud.PNBDigits = length(num2str(ISAACINFO.ImMaxPlans));
ud.Plan = 1;
ud.DynMin = 0;
ud.DynMax = 1;
set(h0,'UserData',ud);
addpath(ud.ToolDir)
IsaacEventUpdListe(h0,ud.ToolDir,'ImageAjust_upd') % abonnement aux vnements
cible = IsaacImageCible;
if isempty(cible)
	ImageAjust_upd(h0,1,cible,h0)
else
	ImageAjust_upd(h0,2,cible,h0)
end
% auteur = ho car accepte les vnements causs par soi-mme pour mise  jour graphique