function IsaacModBox(modname,dirname)
% Boite  modules
%
% Appell par la slection d'un module dans le menu
% Peut tre lanc en plusieurs exemplaires
%
%  - modname	: nom du module
%  - dirname	: nom complet du rpertoire parent du module
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

% structure ud : champ UserData
%	InfoHnd		: handle du dialog d'info modules
%	ModName		: nom du module
%	ModDirName	: nom du rpertoire parent du module
%	ParamInfo	: cellarray {{e}{s}} des types de paramtres d'entre/sortie
%	ParamNb		: [nb de paramtres d'entre, nb de paramtres de sortie]
%	Param       : cellarray {[e][s]} : une structure pour chaque paramtre
%		.label	: nom abrg du paramtre
%		.nom     : info gnrique si non valid ou nom du param quand valid
%		.affi    : valeur affiche dans la liste d'entree/sortie
%		.ok		: true si paramtre valid
%		.val     : valeur du param valid
%		.options : matrice des choix possibles pour param slectionn
%		.opidx	: index de l'option slectionne dans tableau options
%	PIndex		: indice [i,j] dans Param du paramtre en cours d'dition
%	PTarget		: 0= aucun, 1= base workspace, 2= image cible, 3= mmoire, 4= fichier,5= MATLAB
%	PVarName		: nom de la variable associe au paramtre dit
%	WSVarName	: si param = @IsaacDATA, nom de la variable cible (valeur de l'objet)

% Valeurs possibles des lments de Param{}.options :
%  1 : valeur variable Base Workspace (@IsaacDATA uniquement)
%	2 : image cible
%	3 : mmoire
%	4 : fichier
%	5 : MATLAB

%---------------------------------------------------------------------------------------------------

global ISAACPREF
global ISAACCONST

% figure(position selon ISAACCONST.DefPos)
h0 = figure( ...
	'CloseRequestFcn','IsaacModBox_cb CloseBox', ...
	'Name',modname, ...
	'Position',IsaacFenPos(ISAACCONST.DefPos(1),ISAACCONST.DefPos(2),320,390,0), ...
	'Tag','IsaacModBox');
	
IsaacDefaultProperties(h0)

% radiobouton entre	
uicontrol('Parent',h0, ...
	'Callback','IsaacModBox_cb RadButListe_E', ...
	'ForegroundColor',ISAACPREF.TextColor2, ...
	'Position',[5 370 100 15], ...
	'String','Entree', ...
	'Style','radiobutton', ...
	'Tag','RadButListe_E');
% liste Param entre
% FontName = Monospaced pour une police non proportionnelle
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACPREF.IsaacColor2, ...
	'Callback','IsaacModBox_cb ListParam_E', ...
	'FontName','Monospaced', ...
	'Position',[5 265 310 100], ...
	'SelectionHighlight','off', ... 
	'Style','listbox', ...
	'Tag','ListParam_E');
% radiobouton sortie	
uicontrol('Parent',h0, ...
	'Callback','IsaacModBox_cb RadButListe_S', ...
	'ForegroundColor',ISAACPREF.TextColor2, ...
	'Position',[5 245 100 15], ...
	'String','Sortie', ...
	'Style','radiobutton', ...
	'Tag','RadButListe_S');
% liste Param sortie
% FontName = Monospaced pour une police non proportionnelle
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACPREF.IsaacColor2, ...
	'Callback','IsaacModBox_cb ListParam_S', ...
	'FontName','Monospaced', ...
	'Position',[5 140 310 100], ...
	'SelectionHighlight','off', ...
	'Style','listbox', ...
	'Tag','ListParam_S');
% text TargetInfo  ---------------------------------------------------------------------------------	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACPREF.IsaacColor2, ...
	'Enable','inactive', ...
	'FontSize',ISAACPREF.FontSize + 1, ...
	'Position',[5 115 310 15], ...
	'Style','text', ...
	'Tag','StxtTargetInfo');
% Bouton radio Param workspace
uicontrol('Parent',h0, ...
	'Callback','IsaacModBox_cb RadButParamWS', ...
	'String','Base Workspace', ...
	'Style','radiobutton', ...
	'Position',[5 90 130 15], ...
	'Tag','RadButParamWS');
% edit WSVarname	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACPREF.IsaacColor2, ...
	'Callback','IsaacModBox_cb EtxtWSVarname', ...
	'FontSize',ISAACPREF.FontSize, ...
	'Position',[135 86 180 22], ...
	'Style','edit', ...
	'Tag','EtxtWSVarname');
% Bouton radio Param image cible
uicontrol('Parent',h0, ...
	'Callback','IsaacModBox_cb RadButParamCible', ...
	'String','Image cible', ...
	'Style','radiobutton', ...
	'Position',[5 70 100 15], ...
	'Tag','RadButParamCible');
% Bouton radio Param mmoire
uicontrol('Parent',h0, ...
	'Callback','IsaacModBox_cb RadButParamMem', ...
	'String','Mmoire', ...
	'Style','radiobutton', ...
	'Position',[5 50 100 15], ...
	'Tag','RadButParamMem');
% Bouton radio Param fichier
uicontrol('Parent',h0, ...
	'Callback','IsaacModBox_cb RadButParamFich', ...
	'String','Fichier', ...
	'Style','radiobutton', ...
	'Position',[5 30 100 15], ...
	'Tag','RadButParamFich');
% Bouton radio Param MATLAB
uicontrol('Parent',h0, ...
	'Callback','IsaacModBox_cb RadButParamMATLAB', ...
	'String','MATLAB', ...
	'Style','radiobutton', ...
	'Position',[5 10 100 15], ...
	'Tag','RadButParamMATLAB');
% edit Varname	
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACPREF.IsaacColor2, ...
	'Callback','IsaacModBox_cb EtxtVarname', ...
	'Position',[85 6 80 22], ...
	'Style','edit', ...
	'Tag','EtxtVarname');
% Bouton ParamInfo
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACPREF.IsaacColor2, ...
	'Callback','IsaacModBox_cb ButParamInfo', ...
	'Position',[225 55 90 20], ...
	'String','Info module ...', ...
	'Tag','ButParamInfo');
% Bouton Valider
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACPREF.IsaacColor2, ...
	'Callback','IsaacModBox_cb ButParamValider', ...
	'Position',[225 30 90 20], ...
	'String','Valider', ...
	'Tag','ButParamValider');
% Bouton Executer
uicontrol('Parent',h0, ...
	'BackgroundColor',ISAACPREF.IsaacColor2, ...
	'Callback','IsaacModBox_cb ButDo', ...
	'Position',[225 5 90 20], ...
	'String','Executer', ...
	'Tag','ButDo');

%---------------------------------------------------------------------------------------------------

% Initialisation avec le module choisi

ud.ModName = modname;
ud.ModDirName = dirname;
ud.InfoHnd = [];
set(h0,'UserData',ud)
LoadModule(h0)
IsaacEventUpdListe(h0,ISAACCONST.ProgDir,'IsaacModBox_upd') % abonnement aux vnements

%---------------------------------------------------------------------------------------------------

function LoadModule(fighnd)

ud = get(fighnd,'UserData');
% initialisations
ud.ParamInfo = cell(1,2);
ud.ParamNb = [0,0];
ud.Param = cell(1,2);
ud.PIndex = [0,0];
ud.PVarName = 'x';
ud.WSVarName = 'v';
ud.PTarget = 0;
set(findobj(fighnd,'Tag','RadButListe_E'),'Enable','off','Value',0);
set(findobj(fighnd,'Tag','ListParam_E'),'Enable','off','String','','Value',1)
set(findobj(fighnd,'Tag','RadButListe_S'),'Enable','off','Value',0);
set(findobj(fighnd,'Tag','ListParam_S'),'Enable','off','String','','Value',1)
set(findobj(fighnd,'Tag','StxtTargetInfo'),'String','')
set(findobj(fighnd,'Tag','RadButParamWS'),'Enable','off','Value',0)
set(findobj(fighnd,'Tag','RadButParamCible'),'Enable','off','Value',0)
set(findobj(fighnd,'Tag','RadButParamMem'),'Enable','off','Value',0)
set(findobj(fighnd,'Tag','RadButParamFich'),'Enable','off','Value',0)
set(findobj(fighnd,'Tag','RadButParamMATLAB'),'Enable','off','Value',0)
set(findobj(fighnd,'Tag','EtxtWSVarname'),'String',ud.WSVarName,'Visible','off')
set(findobj(fighnd,'Tag','EtxtVarname'),'String',ud.PVarName,'Visible','off')
set(findobj(fighnd,'Tag','ButParamValider'),'Enable','off')
set(findobj(fighnd,'Tag','ButDo'),'Enable','off')
% appel du module avec '-f' => retour = types des params du module
try
    [ud.ParamInfo{1},ud.ParamInfo{2}] = IsaacModule(ud.ModName,'-f');
catch exception
	IsaacMessageErreur(['module ',ud.ModName],IsaacError(exception))
	set(fighnd,'UserData',ud)
	return
end
% dcryptage des paramtres du module
try
	if mod(numel([ud.ParamInfo{1:2}]),2)
		% nombre impaire de valeurs
		error('pour provoquer le catch')
	end	
	ud.ParamNb = [size(ud.ParamInfo{1},2)/2,size(ud.ParamInfo{2},2)/2];
	for i = 1:2
		for j = 1:ud.ParamNb(i)
            ud.Param{i}(j).label = ud.ParamInfo{i}{2*j-1};
            ud.Param{i}(j).nom = ud.ParamInfo{i}{2*j};
			switch ud.Param{i}(j).label
                case 'IMG'
                    options = {[2,3,4,5],[2,3,4,5]};
                case 'Image'
                    options = {[2,5],5};
                case 'ROI'
                    options = {[2,3,4,5],[2,3,4,5]};
					% objet @IsaacROI de l'image ouverte si option = 2
                case 'ECOL'
                    options = {[2,3,4,5],[2,3,4,5]};
					% objet @IsaacECOL de l'image ouverte si option = 2
                case 'HISTO'
                    options = {[3,4,5],[3,4,5]};	
                case 'LPIX'
                    options = {[3,4,5],[3,4,5]};	
                case 'DATA'
                    options = {[1,3,4,5],[1,3,4,5]};
				otherwise
					error('pour provoquer le catch')
			end
			ud.Param{i}(j).affi = sprintf('%-10s: %s',ud.Param{i}(j).label,ud.Param{i}(j).nom);
			ud.Param{i}(j).ok = false;
			ud.Param{i}(j).val = [];
			ud.Param{i}(j).options = options{i};
			if ~isempty(ud.Param{i}(j).options)
				ud.Param{i}(j).opidx = 1; % option slectionne = la 1re par dfaut
			else
				ud.Param{i}(j).opidx = 0;
			end	
		end	
	end	
catch
	IsaacMessageErreur(['module ',ud.ModName],'dfinition incorrecte des paramtres')
	set(fighnd,'UserData',ud)
	return
end	
% affichage des paramtres
if ~ud.ParamNb
	set(findobj(fighnd,'Tag','ButDo'),'Enable','on')
else
	% paramtres d'entre
	if ud.ParamNb(1)
		set(findobj(fighnd,'Tag','ListParam_E'),'Enable','on','String',{ud.Param{1}.affi})
		ud.PIndex = [1,1]; % liste entre, param 1
		set(findobj(fighnd,'Tag','RadButListe_E'),'Enable','on','Value',1)
		set(findobj(fighnd,'Tag','RadButListe_S'),'Value',0)
	else
		ud.PIndex = [2,1]; % liste sortie, param 1
		set(findobj(fighnd,'Tag','RadButListe_E'),'Enable','off')
		set(findobj(fighnd,'Tag','RadButListe_S'),'Enable','on','Value',1)
	end
	% paramtres de sortie
	if ud.ParamNb(2)
		set(findobj(fighnd,'Tag','ListParam_S'),'Enable','on','String',{ud.Param{2}.affi})
		set(findobj(fighnd,'Tag','RadButListe_S'),'Enable','on')
	end
	if ~isempty(ud.Param{ud.PIndex(1)}(ud.PIndex(2)).options)
		% option slectionne = la 1re par dfaut
		ud.PTarget = ud.Param{ud.PIndex(1)}(ud.PIndex(2)).options(1);
	end	
end
set(fighnd,'UserData',ud)
% maj options
IsaacModBox_majopt(fighnd,0);
